@@ -1,7 +1,7 @@
 package Perinci::Examples::Bin::Lite;
 
-our $DATE = '2014-11-20'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 
@@ -20,7 +20,7 @@ Perinci::Examples::Bin::Lite - Perinci example CLI scripts (using Perinci::CmdLi
 
 =head1 VERSION
 
-This document describes version 0.04 of Perinci::Examples::Bin::Lite (from Perl distribution Perinci-Examples-Bin-Lite), released on 2014-11-20.
+This document describes version 0.05 of Perinci::Examples::Bin::Lite (from Perl distribution Perinci-Examples-Bin-Lite), released on 2015-09-03.
 
 =head1 DESCRIPTION
 
@@ -29,10 +29,10 @@ L<Perinci::CmdLine::Lite>.
 
 =head1 SEE ALSO
 
-L<Perinci::Examples::Bin>
-
 L<Perinci::Examples::Bin::Any>
 
+L<Perinci::Examples::Bin::Classic>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin-Lite>.
@@ -55,7 +55,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
